# 🌴 EZ Icons
This packages comes with all the Material icons in black and white. You can code complete your way to the icon you need.

##Install
```shell
pip install ez-icons
```

## Usage
```python
import ez_icons
from ez_icons import i, c

layer_icon = ez_icons.get(c.black, i.layers)

```


